@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20250530';
+our $VERSION = '0.20250630';
 
-# Table last modified: 2025-05-30
+# Table last modified: 2025-06-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -37,7 +37,7 @@ our %ZIP_TABLE = (
     '030' => '(?:(?:8(?:5(?:3[03]|7[047]|8[058]|0[235]|[14][0135]|5[02-8]|2[0-4]|6[0167])|6(?:04|22|49|55|77|86|6[78]|1[01]))|01(?:9[26-8]|8[013-68])|1(?:49[26]|393|798)))',
     '031' => '(?:8(?:5(?:20|5[158]|4[3-5]|3[38]|7[07]|8[58]|0[1457]|1[01])|6(?:55|86|1[17]|0[18])))',
     '033' => '(?:86(?:04|66|88))',
-    '034' => '(?:(?:8(?:6(?:05|28|1[358])|5(?:65|78))|039[238]))',
+    '034' => '(?:(?:8(?:6(?:05|28|1[358])|5(?:65|78))|039[38]))',
     '035' => '(?:8686)',
     '036' => '(?:(?:8(?:5(?:11|22|45|77|0[1-3]|5[018]|6[0-47]|8[58]|3[038])|6(?:01|42|55|66|8[689])|7(?:77|88))|1(?:59[23]|393|492)|039[26]))',
     '037' => '(?:(?:86(?:01|55|86)|0392))',
@@ -107,14 +107,14 @@ our %ZIP_TABLE = (
     '101' => '(?:8(?:6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|2[12459]|5[0169])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|1[0-2479]|2[0146]|8[489]|3[037])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|6[356]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|6[356]|7[07-9]|5[0-35-7]|8[013689]|3[02358]|2[1-58]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|0[1-478]|[46][014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|4[0-7]|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|1[126-9]|3[14]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:20|4[0289]|7[013]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|2[28]|1[125-7]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|0[6-8]|1[2-6]|2[235]|3[36])|408|807))',
-    '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
+    '111' => '(?:8(?:6(?:3[01379]|1[0-258]|2[0-358]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[0178]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
@@ -158,7 +158,7 @@ our %ZIP_TABLE = (
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
     '168' => '(?:8(?:5(?:[6-8]0|48|1[0-26]|5[058]|2[05]|0[13468]|3[035])|6(?:2[06]|[18][16]|0[18])|081))',
-    '169' => '(?:8(?:5(?:8[06]|0[39]|2[0-25-7]|5[0568]|1[6-8]|6[18]|7[078]|4[01]|3[15])|6(?:39|77|5[05]|0[58]|1[0-36]|[46][48])|0(?:50|77|1[12])|7(?:[01]1|22)|(?:88|91)5|228))',
+    '169' => '(?:8(?:5(?:8[06]|0[39]|2[0-25-7]|5[0568]|1[6-8]|6[18]|7[078]|4[01]|3[15])|6(?:[23]9|77|5[05]|0[58]|1[0-36]|[46][48])|0(?:50|77|1[12])|7(?:[01]1|22)|(?:88|91)5|228))',
     '170' => '(?:(?:8(?:4(?:1[015-79]|7[0467]|2[013467]|0[124-69]|4[0-248]|5[015-9]|6[0256]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
     '171' => '(?:8(?:5(?:5[23578]|2[0-7]|3[19]|7[027]|4[045]|1[0-268]|6[0189]|0[1-3578]|8[0268])|422))',
     '173' => '(?:8(?:5(?:[06]1|[23]0|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|3[29]|1[01]|0[1256])|710))',
@@ -241,7 +241,7 @@ our %ZIP_TABLE = (
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
     '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|5[46]|4[2578]|6[0-35-8]|7[0-357]|2[0-24-7]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:33|1[02357]|0[137]|2[02])))',
     '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|8[0-25-8]|7[57]|5[0248]|0[1-478]|4[145]|2[0-28])|6(?:86|0[1-39])|733))',
-    '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
+    '262' => '(?:8(?:5(?:0[26]|1[0-2])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|6[06]|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
@@ -251,7 +251,7 @@ our %ZIP_TABLE = (
     '272' => '(?:(?:85(?:01|73|4[03]|5[058]|2[02]|8[0158]|1[0-468]|6[01]|3[038])|01(?:88|9[35])))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|10|27)|7(?:10|33))|019[235-7]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
-    '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
+    '275' => '(?:8(?:5(?:02|11|33|2[058]|8[0158]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[3-7]))',
     '277' => '(?:8(?:5(?:2[0-25]|1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|7[0-479]|6[1-689])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:10|21|33|7[07]|5[05])|6(?:01|86)))',
@@ -271,7 +271,7 @@ our %ZIP_TABLE = (
     '295' => '(?:(?:0192|8601))',
     '296' => '(?:(?:860[12]|0197))',
     '297' => '(?:(?:8(?:5(?:[01]1|33|67|88|5[058])|6(?:11|22|66))|0(?:19[2-8]|29[28])))',
-    '298' => '(?:(?:029[25-7]|8501))',
+    '298' => '(?:(?:0(?:29[25-7]|192)|8501))',
     '299' => '(?:(?:4(?:39[24-7]|[126]92|49[23])|0(?:19[24-8]|29[235-8])|2(?:[1245]92|79[25])|5(?:29[25]|192)|119[245]))',
     '300' => '(?:(?:0(?:3(?:88|9[2-8])|19[235]|49[26]|59[35]|[67]92)|2(?:6(?:86|9[258])|49[2-578]|79[2357]|395|593)|1(?:29[24-6]|19[235]|[3-5]92|696)|8(?:5(?:50|67|88)|6(?:01|19|86))|4(?:29[35]|193|495|598)|3(?:59[258]|29[45])))',
     '301' => '(?:8(?:6(?:0[12]|1[01])|5(?:55|0[15])))',
@@ -317,7 +317,7 @@ our %ZIP_TABLE = (
     '341' => '(?:85(?:01|5[058]|2[67]))',
     '342' => '(?:8(?:50[125]|601))',
     '343' => '(?:(?:8(?:5(?:[24]0|11|85|5[458]|0[12])|6(?:01|86))|019[23]))',
-    '344' => '(?:8(?:5(?:11|40|55|66|7[78]|3[35]|8[58]|2[12]|0[68])|68[06]))',
+    '344' => '(?:8(?:5(?:11|40|55|66|7[78]|3[35]|8[58]|2[12]|0[68])|68[016]))',
     '345' => '(?:850[1248])',
     '346' => '(?:(?:8(?:5(?:[34]0|24|[01][16])|68[56])|01(?:8[13]|9[2-68])))',
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
@@ -393,7 +393,7 @@ our %ZIP_TABLE = (
     '417' => '(?:8(?:5(?:6[05-7]|3[01358]|1[0-259]|8[058]|0[135-8]|5[05]|7[0157]|2[029]|4[035])|6(?:[15]0|32|86|0[19])))',
     '418' => '(?:(?:86(?:[68]6|01)|0192))',
     '419' => '(?:0(?:19[23]|29[35]|392))',
-    '420' => '(?:8(?:6(?:44|50|6[06]|2[02-48]|0[1-468]|8[0158]|7[07]|3[0369]|1[0-268])|5(?:70|2[1378]|1[027]|3[6-8]|8[0158]|6[07]|5[0578]|0[237-9])|7(?:71|0[3469]|3[39]|[12][02]|6[01])))',
+    '420' => '(?:8(?:6(?:44|50|6[06]|2[02-48]|0[1-468]|8[0158]|7[07]|3[0369]|1[0-268])|5(?:70|2[1378]|1[027]|8[0158]|6[07]|3[67]|5[0578]|0[237-9])|7(?:71|0[3469]|3[39]|[12][02]|6[01])))',
     '421' => '(?:(?:0(?:1(?:88|9[23578])|39[2-7]|59[23568]|49[2356]|29[238])|3(?:29[25-7]|392)|1(?:298|392)))',
     '422' => '(?:8(?:5(?:45|50|8[015]|[26]\d|0[24-79]|7[013-68]|3[01]|1[0-24-9])|6(?:5[04]|3[03]|7[07]|8[068]|6[68]|1[059]|2[0-28])|7(?:66|87)))',
     '424' => '(?:(?:8(?:6(?:48|50|0[1-3]|7[78]|3[1367]|[68][68]|1[01]|2[024])|7(?:82|3[04]|2[0147]|5[0-25]|6[07]|0[18]|1[579])|5(?:66|0[23]|5[058]|1[01]))|0(?:19[23]|292)))',
@@ -417,11 +417,11 @@ our %ZIP_TABLE = (
     '443' => '(?:(?:8(?:5(?:[05]5|88)|6[01]1)|019[2-4]))',
     '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|2[025]|1[0-25-7]|4[0235]|8[01568]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:[58]5|1[01]|0[1-35])|60[12]))',
-    '446' => '(?:8(?:5(?:40|2[0-356]|1[124578]|5[058]|3[35]|0[1-8]|8[58])|6(?:35|41|86|0[12])))',
+    '446' => '(?:8(?:5(?:40|2[0-356]|1[124578]|5[058]|0[1-8]|8[58]|3[035])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:1[0-2]|0[1-3578])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:11|50|0[156]|2[35]|3[13-5]|4[023])|731))',
     '449' => '(?:029[23])',
-    '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[248]0|[05]1|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
+    '450' => '(?:(?:8(?:5(?:[45]0|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[248]0|[05]1|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
     '453' => '(?:8(?:5(?:01|40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|1[0-28])|6(?:[28]6|62|0[18])|7(?:58|77|0[14])))',
@@ -470,9 +470,9 @@ our %ZIP_TABLE = (
     '497' => '(?:8(?:5(?:[04][158]|3[138]|2[27]|1[0-2])|60[12]))',
     '498' => '(?:850[1-35])',
     '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|2[1-357-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378])))',
-    '501' => '(?:(?:0(?:69[2-8]|29[2-6]|49[25-8]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|592)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
-    '502' => '(?:8(?:5(?:[12]1|58|67|85|0[13])|792))',
-    '503' => '(?:(?:8(?:5(?:5[02-46-9]|2[0-3]|[01][1-9]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[28]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
+    '501' => '(?:(?:0(?:69[2-8]|49[25-8]|29[346]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|592)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
+    '502' => '(?:85(?:[12]1|58|67|85|0[13]))',
+    '503' => '(?:(?:8(?:5(?:2[0-3]|[01][1-9]|5[02-4679]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[28]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
     '504' => '(?:8(?:5(?:[48]5|11|0[14]|5[15])|7(?:10|0[12])|6(?:01|42)))',
     '505' => '(?:(?:8(?:5(?:10|0[1358])|60[36])|0392))',
     '506' => '(?:(?:8(?:6(?:66|78|90|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
@@ -770,7 +770,7 @@ our %ZIP_TABLE = (
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|3[134679]|4[28]|6[02-79]|7[03-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[2358]|49[2568]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
-    '812' => '(?:(?:8(?:6(?:8[0134679]|[03][1-9]|4[0-35-8]|7[025-8]|5[0-79]|1[0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
+    '812' => '(?:(?:8(?:6(?:8[0134679]|[03][1-9]|4[0-35-8]|7[025-8]|5[0-79]|1[0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|4[0-8]|6[0-69])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|77|1[39]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:65|77|0[135]|8[58]|1[0-2]|2[0245]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
@@ -817,7 +817,7 @@ our %ZIP_TABLE = (
     '856' => '(?:8(?:5(?:[58]5|16|77|6[0-28])|6(?:70|86|0[19])))',
     '857' => '(?:(?:8(?:5(?:33|58|66|0[1-38]|8[58]|7[57]|1[01])|6(?:[68]6|11))|2(?:49[24]|392)|4(?:495|592)|119[2-578]|0[134]92))',
     '858' => '(?:85(?:01|55|8[0589]))',
-    '859' => '(?:(?:3(?:79[2378]|29[238]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
+    '859' => '(?:(?:3(?:29[2368]|79[2378]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
     '860' => '(?:8(?:5(?:3[013469]|8[014-8]|7[057]|[01][1-9]|6[5-8]|5[0-24-8]|4[01357]|2[0-8])|6(?:2[245]|1[1589]|8[168]|5[05]|0[1-68]|6[08])|7(?:39|9[25-7])))',
     '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[23568])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[2-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|85(?:01|14|38|2[089])|2(?:29[35-7]|[14]92)|6[13]95|7292))',
     '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[359]|0[139]|1[0-2]|8[08]|5[125])|7(?:44|1[06]|9[34]|0[12]|2[01])|5(?:[58]5|10|0[2458]|7[01])))',
@@ -873,7 +873,7 @@ our %ZIP_TABLE = (
     '914' => '(?:(?:8(?:5(?:[14]0|24|67|5[058]|8[05]|0[12])|6(?:09|66|8[68]))|019[258]))',
     '915' => '(?:(?:8(?:5(?:01|55|77|1[015]|3[03]|2[04]|8[568])|666)|0292|1195))',
     '916' => '(?:(?:8(?:5(?:67|5[058]|8[58]|1[05]|0[1578])|6(?:[468]6|01))|0(?:29[235]|[14]92)|1198))',
-    '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|[13]98)))',
+    '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|601)|0(?:29[378]|[13]98)))',
     '918' => '(?:8(?:5(?:6[05-7]|4[03]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[2578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:2[0-25]|4[013-5]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[1-35-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
@@ -919,7 +919,7 @@ our %ZIP_TABLE = (
     '960' => '(?:(?:8(?:5(?:75|4[06]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|0[1-35-9]|1[1-3568])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
-    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[078]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[67])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
+    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[078]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[6-8])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
     '964' => '(?:(?:8(?:5(?:[67]7|01|58)|601)|0[23]92))',
     '965' => '(?:8(?:5(?:[347]0|67|0[1-6]|8[058]|2[02]|5[08]|1[016])|6(?:[01]1|78)))',
     '966' => '(?:(?:0(?:19[2-4]|485)|8601))',
